==> lit_ui_kit-1.0.0.tar.gz: lib/src/widgets/settings_panel/settings_tile.dart <==
import 'package:flutter/material.dart';
import 'package:lit_ui_kit/lit_ui_kit.dart';

class SettingsTile extends StatelessWidget {
  final void Function(bool) onValueToggled;
  final bool enabled;
  final bool darkMode;
  final String optionName;
  final IconData iconData;
  final String disabledLabel;
  final String enabledLabel;

  /// Creates a new [SettingsTile].
  ///
  /// It will be used to display the various settings which
  /// can be toggled on the [SettingsPanel].
  const SettingsTile({
    Key key,
    @required this.onValueToggled,
    @required this.darkMode,
    @required this.enabled,
    @required this.optionName,
    @required this.iconData,
    this.disabledLabel = "off",
    this.enabledLabel = "on",
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints boxConstraints) {
        return Row(
          children: [
            SizedBox(
              width: (boxConstraints.maxWidth) * 0.25,
              child: Icon(
                iconData,
                color: darkMode ? Colors.white : LitColors.mediumGrey,
                size: 18.0,
              ),
            ),
            SizedBox(
              width: (boxConstraints.maxWidth) * 0.5,
              child: ClippedText(
                optionName,
                style: LitTextStyles.sansSerif.copyWith(
                  color: darkMode ? Colors.white : LitColors.mediumGrey,
                  fontSize: 14.0,
                ),
                textAlign: TextAlign.center,
              ),
            ),
            SizedBox(
                width: (boxConstraints.maxWidth) * 0.25,
                child: LitSwitchButton(
                  enabled: enabled,
                  onValueToggle: onValueToggled,
                  enabledBorderColor: LitColors.mintGreen.withOpacity(0.7),
                  disabledBorderColor: LitColors.darkRed.withOpacity(0.5),
                  disabledText: disabledLabel,
                  enabledText: enabledLabel,
                  textStyle: LitTextStyles.sansSerif.copyWith(
                    color: darkMode ? Colors.white : LitColors.mediumGrey,
                    fontSize: 14.0,
                  ),
                ))
          ],
        );
      },
    );
  }
}

==> lit_ui_kit-1.0.2.tar.gz: lib/src/widgets/settings_panel/settings_tile.dart <==
import 'package:flutter/material.dart';
import 'package:lit_ui_kit/lit_ui_kit.dart';

class SettingsTile extends StatelessWidget {
  final void Function(bool) onValueToggled;
  final bool enabled;
  final bool darkMode;
  final String optionName;
  final IconData iconData;
  final String disabledLabel;
  final String enabledLabel;

  /// Creates a new [SettingsTile].
  ///
  /// It will be used to display the various settings which
  /// can be toggled on the [SettingsPanel].
  const SettingsTile({
    Key? key,
    required this.onValueToggled,
    required this.darkMode,
    required this.enabled,
    required this.optionName,
    required this.iconData,
    this.disabledLabel = "off",
    this.enabledLabel = "on",
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints boxConstraints) {
        return Row(
          children: [
            SizedBox(
              width: (boxConstraints.maxWidth) * 0.25,
              child: Icon(
                iconData,
                color: darkMode ? Colors.white : LitColors.mediumGrey,
                size: 18.0,
              ),
            ),
            SizedBox(
              width: (boxConstraints.maxWidth) * 0.5,
              child: ClippedText(
                optionName,
                style: LitTextStyles.sansSerif.copyWith(
                  color: darkMode ? Colors.white : LitColors.mediumGrey,
                  fontSize: 14.0,
                ),
                textAlign: TextAlign.center,
              ),
            ),
            SizedBox(
                width: (boxConstraints.maxWidth) * 0.25,
                child: LitSwitchButton(
                  enabled: enabled,
                  onValueToggle: onValueToggled,
                  enabledBorderColor: LitColors.mintGreen.withOpacity(0.7),
                  disabledBorderColor: LitColors.darkRed.withOpacity(0.5),
                  disabledText: disabledLabel,
                  enabledText: enabledLabel,
                  textStyle: LitTextStyles.sansSerif.copyWith(
                    color: darkMode ? Colors.white : LitColors.mediumGrey,
                    fontSize: 14.0,
                  ),
                ))
          ],
        );
      },
    );
  }
}
